searchData={"items":[{"type":"module","title":"GenCache","doc":"Generic cache layer for anything.\nAllows concurrent requests without work duplication and blocking.\n\nUsage:\n```\n{:ok, pid} = GenCache.start_link()\n\n# populate cache with default `ttl` value\nresponse = GenCache.request(pid, {Mod, :fun, [arg1, arg2]})\n\n# populate cache with custom `ttl` value\nresponse = GenCache.request(pid, {Mod, :fun, [arg1, arg2]}, ttl: :timer.seconds(15))\n```\n\nSpecial notes:\n- we use a map to signify the state of the cache (usually this is an atom)\n- this map contains currently running cache misses\n- every change on this map triggers a state transition in gen_statem\n- the postponed requests get a chance to run again on each state transition","ref":"GenCache.html"},{"type":"function","title":"GenCache.get_state/1","doc":"","ref":"GenCache.html#get_state/1"},{"type":"function","title":"GenCache.remove/2","doc":"","ref":"GenCache.html#remove/2"},{"type":"function","title":"GenCache.remove_expired_entries/2","doc":"","ref":"GenCache.html#remove_expired_entries/2"},{"type":"function","title":"GenCache.request/3","doc":"","ref":"GenCache.html#request/3"},{"type":"function","title":"GenCache.start_link/1","doc":"","ref":"GenCache.html#start_link/1"},{"type":"module","title":"GenCache.Config","doc":"","ref":"GenCache.Config.html"},{"type":"function","title":"GenCache.Config.log_debug/0","doc":"","ref":"GenCache.Config.html#log_debug/0"},{"type":"function","title":"GenCache.Config.log_info/0","doc":"","ref":"GenCache.Config.html#log_info/0"},{"type":"function","title":"GenCache.Config.set_log_level/1","doc":"","ref":"GenCache.Config.html#set_log_level/1"},{"type":"module","title":"GenCache.Data","doc":"","ref":"GenCache.Data.html"},{"type":"module","title":"GenCache.Macro","doc":"","ref":"GenCache.Macro.html"},{"type":"extras","title":"GenCache","doc":"# GenCache\n\nGeneric cache for Elixir. It uses MFA (module / function / arguments) tuples as keys, so you can cache any function call with low development effort.\n\nBy relying on `gen_statem`, it is able to prevent duplicate work on concurrent requests on the same key, while keeping the API simple.\n\nThe generation of the cache value is done in a separate process, so the main GenServer loop is never blocked. Also it is possible to generate multiple different expensive values in parallel, with all the callers waiting for the result. This happens transparently to the caller.\n\nAll thanks to the awesome [gen_statem](https://www.erlang.org/doc/apps/stdlib/gen_statem.html) module.","ref":"readme.html"},{"type":"extras","title":"Usage - GenCache","doc":"```elixir\ndefmodule MyCache do\n  use GenCache\nend\n\n# start the cache, that executes state entries purge every 1 second with a default ttl of 15 seconds\nMyCache.start_link(purge_loop: :timer.seconds(1), default_ttl: :timer.seconds(15))\n\n# this will execute the MFA tuple and store the result in the cache\n# you should see \"Hello World\" printed to the console\nres = MyCache.request({IO, :puts, [\"Hello World\"]})\n\n# this will not execute the MFA tuple and just return the cached result\nres = MyCache.request({IO, :puts, [\"Hello World\"]})\n\n\n# add custom ttl for the given key\nres = MyCache.request({IO, :puts, [\"Quick one\"]}, ttl: :timer.seconds(5))","ref":"readme.html#usage"},{"type":"extras","title":"log debug messages - GenCache","doc":"GenCache.Config.log_debug()","ref":"readme.html#log-debug-messages"},{"type":"extras","title":"log only info messages - GenCache","doc":"GenCache.Config.log_info()\n```","ref":"readme.html#log-only-info-messages"},{"type":"extras","title":"Done - GenCache","doc":"- [x] configurable default timeout\n- [x] periodic cleanup of expired entries\n- [x] protect against raising exceptions in the MFA tuple","ref":"readme.html#done"},{"type":"extras","title":"Installation - GenCache","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `gen_cache` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:gen_cache, \"~> 0.1.0\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}